@@ -19,6 +19,7 @@ PROPS = (
     "user_videos_dir",
     "user_music_dir",
     "user_bin_dir",
+    "site_bin_dir",
     "user_applications_dir",
     "user_runtime_dir",
     "site_data_dir",
@@ -26,6 +27,7 @@ PROPS = (
     "site_cache_dir",
     "site_state_dir",
     "site_log_dir",
+    "site_applications_dir",
     "site_runtime_dir",
 )
 
